# Preferences initialization file for the Tycho tcl/tk Ptolemy interface.
# This file creates and initializes the preference sets used by Tycho.
# The defaults can be over-ridden in the user's tychorc.tcl file.
#
# @Authors: John Reekie
#
# @Version: @(#)Defaults.tcl	1.35 12/15/96
#
# @Copyright (c) 1996-1996 The Regents of the University of California.
# All rights reserved.
# 
# Permission is hereby granted, without written agreement and without
# license or royalty fees, to use, copy, modify, and distribute this
# software and its documentation for any purpose, provided that the
# above copyright notice and the following two paragraphs appear in all
# copies of this software.
# 
# IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
# FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
# ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF
# THE UNIVERSITY OF CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
# 
# THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
# INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE SOFTWARE
# PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
# CALIFORNIA HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
# ENHANCEMENTS, OR MODIFICATIONS.
# 
# 						PT_COPYRIGHT_VERSION_2
# 						COPYRIGHTENDKEY
#
#######################################################################


# FIXME: since this file is now used only to initialize the
# preferences database, it should perhaps be moved and renamed.


#######################################################################
###
# Miscellaneous preferences
#
preference create misc \
	-description "Miscellaneous preferences" \
	-build {

    # The auto-save interval in minutes. A value of zero means no auto-save.
    add autoSaveInterval 5 -description "Auto-save interval (in minutes)"

    # Confirm on exit. On by default.
    add confirmOnExit 1 -type boolean -description "Confirm on program exit"
} 


#######################################################################
###
# Global font specifications
#
# FIXME: Inheritance is bogus
# FIXME: Make a -font type
#
preference create fonts -inherits misc \
	-description "Global font specifications" \
	-build {

    add textFont {Screen 14} -type font
    add displayFont {Times 14} -type font
    add cwFont {Courier 14} -type font
    add entryFont {Helvetica 14} -type font
    add messageFont {Helvetica 12} -type font
    add menuFont {Helvetica 12 bold} -type font

    description \
	    textFont    "Text editor font" \
	    displayFont "Proportional display font" \
	    cwFont      "Constant-width display font" \
	    entryFont   "Entry and listbox font" \
	    messageFont "Font for status messages and the like" \
	    menuFont    "Menu and button font"
}

#######################################################################
###
# Layout preferences.
#
# FIXME: Inheritance is bogus

preference create layout -inherits fonts \
	-description "Global layout preferences" \
	-build {

    add textWidth  80 -type integer
    add textHeight 40 -type integer
    add textRelief raised -type choice -values {raised sunken flat}
    
    add buttonPadX 12
    add buttonPadY 4

    add menuPadX 8
    add menuPadY 4

    description \
	    textWidth     "Default text window width" \
	    textHeight    "Default text window height" \
	    textRelief    "Relief of text widgets" \
	    buttonPadX    "Horizontal padding of buttons" \
	    buttonPadY    "Vertical padding of buttons" \
	    menuPadX      "Horizontal padding of menu buttons" \
	    menuPadY      "Vertical padding of menu buttons"
}

#######################################################################
###
# The "global" preferences.
#
# FIXME: Inheritance is bogus

preference create global -inherits layout


#######################################################################
###
# Text editor preferences include most common color selections,
# including a bunch useful for editing source code. Other colors
# that work reasonably well are: forestGreen, chocolate3, DarkOrange,
# coral, OrangeRed, DeepPink, maroon, magenta, and DarkOrchid.
#
# FIXME: Inheritance is bogus
preference create edittext -inherits global \
	-description "Text editor color preferences" \
	-build { 

    add textForeground black -type color
    add textBackground grey93 -type color

    add parenColor  lightskyblue -type color
    add targetColor lightskyblue -type color
    add selectColor lightyellow -type color

    add commentColor firebrick -type color
    add keywordColor blue -type color
    add fixmeColor   red -type color
    add stringColor  gray50 -type color

    add procColor     blue -type color
    add classColor    blue -type color
    add methodColor   purple -type color
    add variableColor forestGreen -type color
    add optionColor   DeepPink -type color
    add linkColor     blue -type color

    add ptlangKeywordColor coral -type color

    add fillColumn 70 -type integer

    description \
	    textForeground "Text color" \
	    textBackground "Text background color" \
	    parenColor    "Parenthesis match highlight" \
	    selectColor   "Selected text highlight color" \
	    commentColor  "Comment highlight color" \
	    keywordColor  "Keyword highlight color" \
	    stringColor   "String highlight color" \
	    procColor     "Procedure name highlight color" \
	    classColor    "Class name highlight color" \
	    methodColor   "Method name highlight color" \
	    variableColor "Variable highlight color" \
	    linkColor     "Hyperlink highlight color" \
	    ptlangKeywordColor "PtLang keyword highlight color" \
	    fillColumn    "Fill column"
}


#######################################################################
###
# Console windows override some of the console preferences
#
preference create console -inherits edittext \
	-description "Console preferences" \
	-build {

    inherit textWidth  60
    inherit textHeight 8

    add answerForeground blue -type color
    add promptForeground firebrick -type color

    description \
	    answerForeground "Color of result text" \
	    promptForeground "Color of prompt text"
} 


#######################################################################
###
# CommandShell is not being shipped in Tycho0.1.1
#
# The command shell window overrides some defaults of the console
# FIXME: Doesn't work, as the superclass uses the console set!
#
#preference create command -inherits console  \
#	-description "Command shell preferences" \
#	-build {
#
#    inherit textWidth  80
#    inherit textHeight 16
#    inherit parenColor  white
#    inherit targetColor white
#    inherit selectColor
#    inherit textForeground
#    inherit textBackground   LightGrey
#    inherit answerForeground
#    inherit promptForeground firebrick
#}


#######################################################################
###
# HTML viewers need a bunch of other color selections
#
preference create viewhtml -inherits edittext \
	-description "HTML viewer preferences" \
	-build {

    inherit textWidth
    inherit textHeight 40
    inherit textBackground LightGrey
    inherit targetColor
    inherit selectColor

    add  fontSize medium \
	    -type set -values {tiny small medium large huge}

    add  findMatchColor forestGreen -type color
    add  tclColor       cyan4 -type color

    description \
	    findMatchColor "Color of matched text" \
	    tclColor       "Color of embedded Tcl"

#	    fontSize       "Size of body text" \
}


#######################################################################
###
# HTML editors need some additional color selections
#
preference create edithtml -inherits edittext  \
	-description "HTML editor preferences" \
	-build {

    add commandColor maroon -type color
    add pointerColor blue -type color
    add destColor    forestGreen -type color

    # FIXME: provide description strings
    description \
	    commandColor "?commandColor?" \
	    pointerColor "?pointerColor?" \
	    destColor    "?destColor?"
}


#######################################################################
###
# Makefile editors also need some additional color selections
#
preference create editmake -inherits edittext -build {
    inherit variableColor DeepPink
    add     includeColor  blue -type color
    add     ruleColor     forestGreen -type color
    add     refvarColor   purple -type color

    # FIXME: provide description strings
    description \
	    includeColor "?includeColor?" \
	    ruleColor    "?ruleColor?" \
	    refvarColor  "?refvarColor?"
}

#######################################################################
###
# The stack window colors its text a lot
#
preference create stacktrace -inherits edittext  \
	-description "Stack trace preferences" \
	-build {

    inherit textWidth  70
    inherit textHeight 30
    inherit commentColor forestGreen
    add     errorColor red  -type color
    add     titleColor black -type color

    description \
	    errorColor "Error text highlight color" \
	    titleColor "Color of stack trace title"
}


#######################################################################
###
# The preferences for dialog and message boxes start here
#
# FIXME: Inheritance is bogus
preference create dialogs -inherits global  \
	-description "Dialog box preferences" \
	-build {

    add entryWidth 30
    add entryForeground black -type color
    add entryBackground grey90 -type color
    add searchBackgroundColor forestGreen -type color
    add searchForegroundColor white -type color
    add spellBackgroundColor  red -type color
    add spellForegroundColor  white -type color
    add fileBrowserWidth   30 -type integer
    add fileBrowserHeight  12 -type integer
    add fileBrowserUseLastDirectory 1 -type boolean \
            -description "Use the last directory opened as initial default?"
    add indexBrowserWidth  30 -type integer
    add indexBrowserHeight 20 -type integer

    description \
	    entryWidth            "Default width of entry widgets" \
	    entryForeground       "Color of text in entry widgets" \
	    entryBackground       "Color of background in entry widgets" \
	    searchBackgroundColor "Background color of matched search text" \
	    searchForegroundColor "Foreground color of matched search text" \
	    spellBackgroundColor  "Background color of matched spell-check text" \
	    spellForegroundColor  "Foreground color of matched spell-check text" \
	    fileBrowserWidth      "Default width of file browser" \
	    fileBrowserHeight     "Default height of file browser" \
	    indexBrowserWidth     "Default width of index browser" \
	    indexBrowserHeight    "Default height of index browser"
}


preference create revcontrol -inherits dialogs \
	-description "Revision control preferences" \
	-build {
    add versionColor blue -type color
    add commentColor firebrick -type color

    # Types of revision control software, in order of preference.
    # It is assumed that for each type listed, there is a class defined
    # called RevControl$type, where $type is the type, and that this
    # class is derived from RevControl.
    add revisionControlTypes {SCCS RCS}

    # Default options for the "sccs admin" command force there to be ID
    # keywords in the file, and also indicate that 1996 should be replaced with
    # the current year. (Use clock here, as it is much faster than exec date)
    add sccsAdminOptions \
	    "-fq[clock format [clock seconds] -format %Y] -fi " \
	    -description "Options to the \"sccs admin\" command"

    description \
	    versionColor  "Color of version text" \
	    commentColor  "Color of comment text" \
	    revisionControlTypes "Supported revision control types" \
	    sccsAdminOptions "Options to the \"sccs admin\" command"
}


#######################################################################
###################
# Graphics editor preferences
#
preference create graphics -inherits global \
	-description "Graphics editor preferences" \
	-build {

    add canvasColor  azure3 -type color
    add canvasHeight 500 -type integer
    add canvasWidth  600 -type integer

    # Specify types of titles in the order in which they appear on the screen.
    add titleTypes {title subtitle author version copyright}

    # FIXME: Pending better handling of fonts. What we really need is a
    # way of specifying a) default size, b) default typeface, c)
    # size, weight and style relative to the default, and d) color.
    #
    # Font lists
    add defaultFont   {helvetica 14} -type font
    add authorFont    {helvetica 16 bolditalic} -type font
    add copyrightFont {helvetica 14} -type font
    add versionFont   {helvetica 14} -type font
    add subtitleFont  {helvetica 16 bold} -type font
    add titleFont     {helvetica 24 bold} -type font

    # Colors for title text
    add authorColor    firebrick -type color
    add copyrightColor black -type color
    add subtitleColor  blue  -type color
    add titleColor     black -type color
    add versionColor   black -type color

    # Other colors
    add linkColor blue -type color
    add lineColor gray40 -type color

    description \
	    canvasColor      "Canvas background color" \
	    canvasHeight     "Default height of the canvas widget, in pixels" \
	    canvasWidth      "Default width of the canvas widget, in pixels" \
	    titleTypes       "Types of titles" \
	    defaultFont      "Default font" \
	    authorFont       "Title font: author" \
	    copyrightFont    "Title font: copyright" \
	    versionFont      "Title font: version" \
	    subtitleFont     "Title font: sub-title" \
	    titleFont        "Title font: main title" \
	    authorColor      "Title color: author" \
	    copyrightColor   "Title color: copyright" \
	    versionColor     "Title color: version" \
	    subtitleColor    "Title color: sub-title" \
	    titleColor       "Title color: main title" \
	    linkColor        "Color of hyperlinked items" \
	    lineColor        "Color of connecting lines"
}


# Preferences for line diagrams

preference create diagram -inherits graphics \
	-description "Diagram editor preferences" \
	-build {

    # Default start position in the horizontal direction (in pixels).
    add startx 10

    # Default start position (below title) in the vertical direction 
    # (in pixels).
    add starty 5

    # Default vertical spacing (as a fraction of a nominal default)
    add spacingy 1.0

    # Default horizontal spacing (as a fraction of a nominal default)
    add spacingx 1.0

    # Default horizontal offset for children (in pixels).
    add indent 50

    # Default vertical spacing (as a multiplier of font height)
    add vertspacing 1.2

    # Vertices displayed as text have a background box
    add nodeBoxColor azure3 -type color

    description \
	    startx "Default horizontal start position (pixels)" \
	    starty "Default start position in the y direction (pixels)" \
	    spacingx "Default horizontal spacing (relative)" \
	    spacingy "Default vertical spacing (relative)" \
	    indent   "Default horizontal offset of children (pixels)" \
	    vertspacing "Default vertical spacing (relative to font height)" \
            nodeBoxColor "Color of background box for nodes"
}


#######################################################################
###################
# Widget color preferences
#


###########################################################################
# Set the default color palette to the old bisque-based colors.
# This is included explicitly here rather than calling tk_bisque
# to allow for fine tuning of each color or future modification
# of the palette.
#
preference create tkbisquepalette -build {
    add activeBackground    #e6ceb1 
    add activeForeground    black 
    add background          #ffe4c4 
    add disabledForeground  #b0b0b0 
    add foreground          black 
    add highlightBackground #ffe4c4 
    add highlightColor      black 
    add insertBackground    black 
    add selectColor         #b03060 
    add selectBackground    #e6ceb1 
    add selectForeground    black 
    add troughColor         #cdb79e
}

preference create tkdefaultpalette \
	-build {
    add activeBackground    #ececec
    add activeForeground    black
    add background          #d9d9d9
    add disabledForeground  #a3a3a3
    add foreground          black
    add highlightBackground #d9d9d9
    add highlightColor      black
    add insertBackground    black 
    add selectColor         #b03060
    add selectBackground    #c3c3c3
    add selectForeground    black
    add troughColor         #c3c3c3
}

preference create tkpalette -inherits tkdefaultpalette \
	-description "Tk widget color palette" \
	-build {

    inherit activeBackground
    inherit activeForeground
    inherit background      
    inherit disabledForeground
    inherit foreground        
    inherit highlightBackground
    inherit highlightColor     
    inherit insertBackground   
    inherit selectColor        
    inherit selectBackground   
    inherit selectForeground   
    inherit troughColor       

    description \
	    activeBackground     "activeBackground" \
	    activeForeground     "activeForeground" \
	    background           "background" \
	    disabledForeground   "disabledForeground" \
	    foreground           "foreground" \
	    highlightBackground  "highlightBackground" \
	    highlightColor       "highlightColor" \
	    insertBackground     "insertBackground" \
	    selectColor          "selectColor" \
	    selectBackground     "selectBackground" \
	    selectForeground     "selectForeground" \
	    troughColor          "troughColor"
}

proc updateTkPalette {} {
    set arglist {}
    foreach pref {
	activeBackground
	activeForeground
	background
	disabledForeground
	foreground 
	highlightBackground
	highlightColor
	insertBackground
	selectColor
	selectBackground
	selectForeground
	troughColor
    } {
	set color [preference get tkpalette $pref]
	# FIXME: If color is null, we want to set back to the Tk default.
	if { $color != "" } {
	    lappend arglist $pref $color
	}
    }
    eval tk_setPalette $arglist
}

preference commandsubscribe tkpalette bogus updateTkPalette {
    activeBackground
    activeForeground
    background
    disabledForeground
    foreground 
    highlightBackground
    highlightColor
    insertBackground
    selectColor
    selectBackground
    selectForeground
    troughColor
}

# Call to updateTkPalette not needed as long as we are using
# tkdefaultpalette
#
# updateTkPalette
